/*
 * Copyright (c) 2006, Eric Seidel.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * The names of the contributors may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Foundation/Foundation.h>
#import <AddressBook/AddressBook.h>

int main (int argc, const char * argv[]) {
    NSAutoreleasePool * pool = [[NSAutoreleasePool alloc] init];

	NSArray *people = [[ABAddressBook sharedAddressBook] people];
	NSMutableArray *gmailEmails = [NSMutableArray new];
	
	unsigned count = [people count];
	for (unsigned x = 0; x < count; x++) {
		[gmailEmails removeAllObjects];
		ABPerson *person = [people objectAtIndex:x];
		ABMultiValue *emails = [person valueForProperty:kABEmailProperty];
		unsigned emailCount = [emails count];
		for (unsigned i = 0; i < emailCount; i++) {
			NSString *email = [emails valueAtIndex:i];
			if ([email rangeOfString:@"@gmail.com" options:NSCaseInsensitiveSearch].length) {
				[gmailEmails addObject:[NSArray arrayWithObjects:[emails labelAtIndex:i], email, nil]];
			}
		}
		ABMultiValue *jabbers = [person valueForProperty:kABJabberInstantProperty];
		unsigned jabberCount = [jabbers count];
		for (unsigned i = 0; i < jabberCount; i++) {
			NSString *jabber = [jabbers valueAtIndex:i];
			unsigned gmailEmailCount = [gmailEmails count];
			for (unsigned j = 0; j < gmailEmailCount; j++) {
				if ([jabber caseInsensitiveCompare:[[gmailEmails objectAtIndex:j] objectAtIndex:1]] == NSOrderedSame) {
					[gmailEmails removeObjectAtIndex:j];
					break;
				}
			}
		}
		
		ABMutableMultiValue *mutableJabbers = nil;
		unsigned gmailEmailCount = [gmailEmails count];
		for (unsigned j = 0; j < gmailEmailCount; j++) {
			if (!mutableJabbers)
				mutableJabbers = [jabbers mutableCopy];
			if (!mutableJabbers)
				mutableJabbers = [ABMutableMultiValue new];
			NSArray *gmailEmailPair = [gmailEmails objectAtIndex:j];
			NSLog(@"[%@ %@] Adding gtalk address: %@ with label: %@", [person valueForProperty:kABFirstNameProperty],  [person valueForProperty:kABLastNameProperty], [gmailEmailPair objectAtIndex:1], ABLocalizedPropertyOrLabel([gmailEmailPair objectAtIndex:0]));
			[mutableJabbers addValue:[gmailEmailPair objectAtIndex:1] withLabel:[gmailEmailPair objectAtIndex:0]];
		}
		if (mutableJabbers) {
			[person setValue:mutableJabbers forProperty:kABJabberInstantProperty];
			[mutableJabbers release];
		}
	}
	[gmailEmails release];
	[[ABAddressBook sharedAddressBook] save];
	
    [pool release];
    return 0;
}
